nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

PortEna

Struct PortEna 

#[repr(transparent)]
pub struct PortEna(pub u32);
GPIO grouped interrupt port 0 enable register

Tuple Fields

0: u32

Implementations

Source

impl PortEna

pub const fn ena(&self) -> u32

Enable port 0 pin for group interrupt. Bit n corresponds to pin Pm_n of port m. 0 = the port 0 pin is disabled and does not contribute to the grouped interrupt. 1 = the port 0 pin is enabled and contributes to the grouped interrupt.

pub const fn set_ena(&mut self, val: u32)

Enable port 0 pin for group interrupt. Bit n corresponds to pin Pm_n of port m. 0 = the port 0 pin is disabled and does not contribute to the grouped interrupt. 1 = the port 0 pin is enabled and contributes to the grouped interrupt.