nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

PortPol

Struct PortPol 

#[repr(transparent)]
pub struct PortPol(pub u32);
GPIO grouped interrupt port 0 polarity register

Tuple Fields

0: u32

Implementations

Source

impl PortPol

pub const fn pol(&self) -> u32

Configure pin polarity of port m pins for group interrupt. Bit n corresponds to pin PIOm_n of port m. 0 = the pin is active LOW. If the level on this pin is LOW, the pin contributes to the group interrupt. 1 = the pin is active HIGH. If the level on this pin is HIGH, the pin contributes to the group interrupt.

pub const fn set_pol(&mut self, val: u32)

Configure pin polarity of port m pins for group interrupt. Bit n corresponds to pin PIOm_n of port m. 0 = the pin is active LOW. If the level on this pin is LOW, the pin contributes to the group interrupt. 1 = the pin is active HIGH. If the level on this pin is HIGH, the pin contributes to the group interrupt.